#!/bin/sh
# This script sets up your system as follows:
# Hadoop is running with HDFS being hosted at a local directory
# .bashrc now contains the appropriate JAVA_HOME and HADOOP_PREFIX
# bash script setenv.sh is made

export HW_HADOOP_DIR=`pwd`

# THIS IS ONLY CORRECT FOR THE ANDREW MACHINES
# Some andrew machines may have different version, 
# you may need to set JAVA_HOME to, for example,
# export JAVA_HOME=/usr/lib/jvm/java-1.7.0-openjdk-1.7.0.65.x86_64/jre
# Please check the version on your machine.

export JAVA_HOME=$(readlink -f /usr/bin/java | sed "s:bin/java::")
export HADOOP_VERSION=2.7.3

if [ ! -e ~/.bashrc ]
then
	touch ~/.bashrc
fi
echo "export JAVA_HOME=$JAVA_HOME" >> ~/.bashrc

export MY_HADOOP_PORT=9000

# Check if ports available
portOpen=$(netstat -ano|grep 9000 |grep LISTEN | wc -l)
if [ $portOpen -ne 0 ]
then
	echo "Ports necessary to start Hadoop are not available on this machine."
	echo "Please try a different machine"
	exit
fi

echo "Downloading Hadoop..."
wget  http://mirrors.ibiblio.org/apache/hadoop/common/hadoop-2.7.3/hadoop-2.7.3.tar.gz 
echo "Untar Hadoop package..."
tar -xzf hadoop-$HADOOP_VERSION.tar.gz  

echo "setup Hadoop environment variables..."
export HADOOP_HOME=$HW_HADOOP_DIR/hadoop-$HADOOP_VERSION
echo "export HADOOP_PREFIX=$HADOOP_HOME" >> ~/.bashrc
echo "export HADOOP_CONF_DIR=$HADOOP_HOME/etc/hadoop" >> ~/.bashrc
echo "export PATH=$PATH:$HADOOP_HOME/bin" >> ~/.bashrc

source ~/.bashrc

cd $HADOOP_HOME
mkdir $HADOOP_HOME/tmp
mkdir $HADOOP_HOME/hdfs

echo "setup Hadoop configuration files"
cp $HADOOP_CONF_DIR/hadoop-env.sh $HADOOP_CONF_DIR/hadoop-env.sh.bak
cp $HW_HADOOP_DIR/hadoop-env.sh $HADOOP_CONF_DIR/hadoop-env.sh

# Make core-site.xml
echo "<?xml version=\"1.0\" encoding=\"UTF-8\"?>
<?xml-stylesheet type=\"text/xsl\" href=\"configuration.xsl\"?>

<configuration>
  <property>
    <name>hadoop.tmp.dir</name>
    <value>$HADOOP_HOME/tmp</value>
  </property>

  <property>
    <name>fs.defaultFS</name>
    <value>hdfs://localhost:$MY_HADOOP_PORT</value>
  </property>
</configuration>
" > $HADOOP_CONF_DIR/core-site.xml

# Make hdfs-site.xml
echo "<?xml version=\"1.0\" encoding=\"UTF-8\"?>
<?xml-stylesheet type=\"text/xsl\" href=\"configuration.xsl\"?>

<configuration>
    <property>
      <name>dfs.replication</name>
      <value>1</value>
    </property>
</configuration>
" > $HADOOP_CONF_DIR/hdfs-site.xml

# Make mapred-site.xml
echo "<?xml version=\"1.0\" encoding=\"UTF-8\"?>
<?xml-stylesheet type=\"text/xsl\" href=\"configuration.xsl\"?>

<configuration>
    <property>
      <name>mapreduce.framework.name</name>
      <value>yarn</value>
    </property>
</configuration>
" > $HADOOP_CONF_DIR/mapred-site.xml

echo "<?xml version=\"1.0\" encoding=\"UTF-8\"?>
<?xml-stylesheet type=\"text/xsl\" href=\"configuration.xsl\"?>

<configuration>
    <property>
      <name>yarn.nodemanager.aux-services</name>
      <value>mapreduce_shuffle</value>
    </property>
</configuration>
" > $HADOOP_CONF_DIR/yarn-site.xml


#execution
cd $HADOOP_HOME
#format the file system
./bin/hdfs namenode -format

echo "======end of script======"
echo "Make sure you run:"
echo "source ~/.bashrc"
echo "NOW!"
echo "========================="
